@@ -36,7 +36,7 @@ public:
     explicit ImportImapSettingWizard(QWidget *parent = nullptr);
     ~ImportImapSettingWizard();
 
-    void next() Q_DECL_OVERRIDE;
+    void next() override;
 
 private:
     void readConfig();
@@ -45,6 +45,7 @@ private:
     void slotHelpClicked();
     void slotFinishImportData();
     void slotAddSummaryInfo(const QString &name);
+    void slotNeedToImportSettings(bool b);
     QMap<QString, AbstractImapSettingsCheckJob *> mListCheckJob;
 
     ImportImapSettingSearchPage *mSearchPage;
