@@ -22,8 +22,7 @@
 
 #include <QWidget>
 
-namespace Ui
-{
+namespace Ui {
 class SieveEditorConfigureServerWidget;
 }
 
